@@ -14,10 +14,12 @@ import logging
 import pathlib
 import uuid
 
-from typing import Any, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 import aio_pika as apika
 
+from sdsstools.logger import SDSSLogger
+
 from .base import BaseClient
 from .command import Command
 from .model import ModelSet
@@ -75,7 +77,7 @@ class AMQPReply(object):
         # Acknowledges receipt of message
         message.ack()
 
-        self.info: dict[Any, Any] = message.info()
+        self.info: Dict[Any, Any] = message.info()
 
         self.headers = self.info["headers"]
         for key in self.headers:
@@ -158,7 +160,6 @@ class AMQPClient(BaseClient):
         If `None`, the active parser will be used.
     models
         A list of actor models whose schemas will be monitored.
-
     """
 
     __EXCHANGE_NAME__ = "sdss_exchange"
@@ -178,8 +179,8 @@ class AMQPClient(BaseClient):
         version: Optional[str] = None,
         loop: Optional[asyncio.AbstractEventLoop] = None,
         log_dir: Optional[PathLike] = None,
-        log: Optional[logging.Logger] = None,
-        models: list[str] = [],
+        log: Optional[SDSSLogger] = None,
+        models: List[str] = [],
     ):
 
         super().__init__(name, version=version, loop=loop, log_dir=log_dir, log=log)
